#
# spec file for package bogofilter
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor db%{nil}
%if "%flavor" == ""
ExclusiveArch:  do-not-build
%else
%define dash -
%define src -src
%if "%{flavor}" == "db"
%define with_db 1
%endif
%if "%{flavor}" == "sqlite3"
%define with_sqlite3 1
%endif
%if "%{flavor}" == "kyotocabinet"
%define with_kyotocabinet 1
%endif
%endif

%define _name   bogofilter
Name:           %{_name}%{?dash}%{?flavor}%{?src}
Version:        1.2.4
Release:        15.12
Summary:        Fast Anti-Spam Filtering by Bayesian Statistical Analysis
License:        GPL-2.0-or-later
URL:            http://bogofilter.sourceforge.net/
Source:         http://downloads.sourceforge.net/bogofilter/bogofilter-%{version}.tar.bz2
Source10:       README.SUSE
# PATCH-FEATURE-OPENSUSE bogofilter-kyotocabinet.patch --replace tokyocabinet with kyotocabinet following
# tokyocabinet recommendations
Patch0:         bogofilter-kyotocabinet.patch
BuildRequires:  autoconf
BuildRequires:  automake
%if 0%{?with_db}
BuildRequires:  db-devel
%endif
BuildRequires:  flex
BuildRequires:  gsl-devel
BuildRequires:  sharutils
%if 0%{?with_sqlite3}
BuildRequires:  sqlite3-devel
%endif
BuildRequires:  xmlto
%if 0%{?with_kyotocabinet}
BuildRequires:  libkyotocabinet-devel
BuildRequires:  libxml2-tools
%endif

%description
Bogofilter is a Bayesian spam filter.  In normal operation, it takes an
e-mail message or text from standard input, does a statistical check
against lists of "good" and "bad" words, and returns a status code
indicating whether the message is spam.  Bogofilter is designed with
fast algorithms (including the Berkeley DB system), coded directly in
C, and tuned for speed, so it can be used for production by sites that
process a lot of mail.

%package -n %{_name}-common
Summary:        Fast Anti-Spam Filtering by Bayesian Statistical Analysis
Requires:       %{_name}-backend = %{version}
BuildArch:      noarch

%description -n %{_name}-common
Bogofilter is a Bayesian spam filter.  In normal operation, it takes an
e-mail message or text from standard input, does a statistical check
against lists of "good" and "bad" words, and returns a status code
indicating whether the message is spam.  Bogofilter is designed with
fast algorithms (including the Berkeley DB system), coded directly in
C, and tuned for speed, so it can be used for production by sites that
process a lot of mail.

This package contains shared files for various %{_name} backends

%package -n %{_name}-doc
Summary:        Bogofilter documentation
BuildArch:      noarch

%description -n %{_name}-doc
This package contains the documentation of %{_name}

%package -n %{_name}-kyotocabinet
Summary:        Bogofilter kyotocabinet backend
Requires:       %{_name}-common = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       %{_name}-backend = %{version}-%{release}
Provides:       %{_name}-tokyocabinet = %{version}
# Please remove the "=" of the obsoletes tag with the next update
Obsoletes:      %{_name}-tokyocabinet <= %{version}

%description -n %{_name}-kyotocabinet
This package contains %{_name} build with the tokyocabinet backend.

%package -n %{_name}-sqlite3
Summary:        Bogofilter sqlite3 backend
Requires:       %{_name}-common = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       %{_name}-backend = %{version}-%{release}
%if 0%{?suse_version} == 1310
Conflicts:      %{_name}-db
%endif

%description -n %{_name}-sqlite3
This package contains %{_name} build with the sqlite3 backend.

%package -n %{_name}-db
Summary:        Bogofilter libdb backend
Requires:       %{_name}-common = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       %{_name} = %{version}-%{release}
Obsoletes:      %{_name}
Provides:       %{_name}-backend = %{version}-%{release}
%if 0%{?suse_version} == 1310
Conflicts:      %{_name}-sqlite3
%endif

%description -n %{_name}-db
This package contains %{_name} build with the libdb backend.

%prep
%setup -q -n %{_name}-%{version}
%if 0%{?suse_version} > 1320
%patch0 -p1
%endif

%build
autoreconf -fiv
%configure \
	--with-database=%{flavor} \
	--program-suffix=-%{flavor}
make %{?_smp_mflags}

%install
%make_install
# create a dummy target for alternatives
install -d %{buildroot}%{_sysconfdir}/alternatives
for i in bogofilter bogolexer bogotune bogoutil bf_compact bf_copy bf_tar; do
	touch %{buildroot}%{_sysconfdir}/alternatives/${i}
	touch %{buildroot}%{_sysconfdir}/alternatives/${i}.1.gz
	ln -s %{_sysconfdir}/alternatives/${i} %{buildroot}%{_bindir}/${i}
%if "%{flavor}" == "db"
	ln -s %{_sysconfdir}/alternatives/${i}.1.gz %{buildroot}%{_mandir}/man1/${i}.1.gz
%endif
done
%if "%{flavor}" == "db"
mv %{buildroot}/%{_sysconfdir}/bogofilter.cf.example %{buildroot}/%{_sysconfdir}/bogofilter.cf
# bogoupgrade is written in perl and therefore belongs to the common package
mv %{buildroot}/%{_bindir}/bogoupgrade-db %{buildroot}/%{_bindir}/bogoupgrade
mv %{buildroot}/%{_mandir}/man1/bogoupgrade-db.1 %{buildroot}/%{_mandir}/man1/bogoupgrade.1

for d in contrib; do
	install -d %{buildroot}%{_datadir}/%{_name}/${d}
	files=$( find ${d} -maxdepth 1 -type f)
	for f in ${files} ; do
		case ${f} in
			*.c|*.o|*.obj|*/Makefile*) continue ;;
			*.1)
				cp -p ${f} %{buildroot}/%{_mandir}/man1 ;;
			*)
				cp -p ${f} %{buildroot}/%{_datadir}/%{_name}/${d}
				head -n 1 ${f} | grep -q "^#\!" && \
					chmod 0755 %{buildroot}/%{_datadir}/%{_name}/${d}/${f##*/}
				;;
		esac
	done
done
# add a vendor README to the doc package
install -D -m 0644 %{SOURCE10} %{buildroot}/%{_defaultdocdir}/bogofilter-doc/README.SUSE
%else
rm %{buildroot}/%{_bindir}/bogoupgrade-*
rm %{buildroot}/%{_mandir}/man1/bogoupgrade-*
rm %{buildroot}/%{_sysconfdir}/bogofilter.cf.example
%endif

%if "%{flavor}" == "kyotocabinet"
%post -n %{_name}-kyotocabinet
%{_sbindir}/update-alternatives --install %{_bindir}/bogofilter bogofilter %{_bindir}/bogofilter-kyotocabinet 10 \
 --slave %{_mandir}/man1/bogofilter.1.gz bogofilter.1.gz %{_mandir}/man1/bogofilter-kyotocabinet.1.gz \
 --slave %{_bindir}/bogolexer bogolexer %{_bindir}/bogolexer-kyotocabinet \
 --slave %{_mandir}/man1/bogolexer.1.gz bogolexer.1.gz %{_mandir}/man1/bogolexer-kyotocabinet.1.gz \
 --slave %{_bindir}/bogotune bogotune %{_bindir}/bogotune-kyotocabinet \
 --slave %{_mandir}/man1/bogotune.1.gz bogotune.1.gz %{_mandir}/man1/bogotune-kyotocabinet.1.gz \
 --slave %{_bindir}/bogoutil bogoutil %{_bindir}/bogoutil-kyotocabinet \
 --slave %{_mandir}/man1/bogoutil.1.gz bogoutil.1.gz %{_mandir}/man1/bogoutil-kyotocabinet.1.gz \
 --slave %{_bindir}/bf_compact bf_compact %{_bindir}/bf_compact-kyotocabinet \
 --slave %{_mandir}/man1/bf_compact.1.gz bf_compact.1.gz %{_mandir}/man1/bf_compact-kyotocabinet.1.gz \
 --slave %{_bindir}/bf_copy bf_copy %{_bindir}/bf_copy-kyotocabinet \
 --slave %{_mandir}/man1/bf_copy.1.gz bf_copy.1.gz %{_mandir}/man1/bf_copy-kyotocabinet.1.gz \
 --slave %{_bindir}/bf_tar bf_tar %{_bindir}/bf_tar-kyotocabinet \
 --slave %{_mandir}/man1/bf_tar.1.gz bf_tar.1.gz %{_mandir}/man1/bf_tar-kyotocabinet.1.gz

%postun -n %{_name}-kyotocabinet
if [ ! -f %{_bindir}/bogofilter-kyotocabinet ] ; then
	%{_sbindir}/update-alternatives --remove bogofilter %{_bindir}/bogofilter-kyotocabinet
fi
%endif

%if "%{flavor}" == "sqlite3"
%post -n %{_name}-sqlite3
%{_sbindir}/update-alternatives --install %{_bindir}/bogofilter bogofilter %{_bindir}/bogofilter-sqlite3 30 \
 --slave %{_mandir}/man1/bogofilter.1.gz bogofilter.1.gz %{_mandir}/man1/bogofilter-sqlite3.1.gz \
 --slave %{_bindir}/bogolexer bogolexer %{_bindir}/bogolexer-sqlite3 \
 --slave %{_mandir}/man1/bogolexer.1.gz bogolexer.1.gz %{_mandir}/man1/bogolexer-sqlite3.1.gz \
 --slave %{_bindir}/bogotune bogotune %{_bindir}/bogotune-sqlite3 \
 --slave %{_mandir}/man1/bogotune.1.gz bogotune.1.gz %{_mandir}/man1/bogotune-sqlite3.1.gz \
 --slave %{_bindir}/bogoutil bogoutil %{_bindir}/bogoutil-sqlite3 \
 --slave %{_mandir}/man1/bogoutil.1.gz bogoutil.1.gz %{_mandir}/man1/bogoutil-sqlite3.1.gz \
 --slave %{_bindir}/bf_compact bf_compact %{_bindir}/bf_compact-sqlite3 \
 --slave %{_mandir}/man1/bf_compact.1.gz bf_compact.1.gz %{_mandir}/man1/bf_compact-sqlite3.1.gz \
 --slave %{_bindir}/bf_copy bf_copy %{_bindir}/bf_copy-sqlite3 \
 --slave %{_mandir}/man1/bf_copy.1.gz bf_copy.1.gz %{_mandir}/man1/bf_copy-sqlite3.1.gz \
 --slave %{_bindir}/bf_tar bf_tar %{_bindir}/bf_tar-sqlite3 \
 --slave %{_mandir}/man1/bf_tar.1.gz bf_tar.1.gz %{_mandir}/man1/bf_tar-sqlite3.1.gz

%postun -n %{_name}-sqlite3
if [ ! -f %{_bindir}/bogofilter-sqlite3 ] ; then
	%{_sbindir}/update-alternatives --remove bogofilter %{_bindir}/bogofilter-sqlite3
fi
%endif

%if "%{flavor}" == "db"
%post -n %{_name}-db
%{_sbindir}/update-alternatives --install %{_bindir}/bogofilter bogofilter %{_bindir}/bogofilter-db 50 \
 --slave %{_mandir}/man1/bogofilter.1.gz bogofilter.1.gz %{_mandir}/man1/bogofilter-db.1.gz \
 --slave %{_bindir}/bogolexer bogolexer %{_bindir}/bogolexer-db \
 --slave %{_mandir}/man1/bogolexer.1.gz bogolexer.1.gz %{_mandir}/man1/bogolexer-db.1.gz \
 --slave %{_bindir}/bogotune bogotune %{_bindir}/bogotune-db \
 --slave %{_mandir}/man1/bogotune.1.gz bogotune.1.gz %{_mandir}/man1/bogotune-db.1.gz \
 --slave %{_bindir}/bogoutil bogoutil %{_bindir}/bogoutil-db \
 --slave %{_mandir}/man1/bogoutil.1.gz bogoutil.1.gz %{_mandir}/man1/bogoutil-db.1.gz \
 --slave %{_bindir}/bf_compact bf_compact %{_bindir}/bf_compact-db \
 --slave %{_mandir}/man1/bf_compact.1.gz bf_compact.1.gz %{_mandir}/man1/bf_compact-db.1.gz \
 --slave %{_bindir}/bf_copy bf_copy %{_bindir}/bf_copy-db \
 --slave %{_mandir}/man1/bf_copy.1.gz bf_copy.1.gz %{_mandir}/man1/bf_copy-db.1.gz \
 --slave %{_bindir}/bf_tar bf_tar %{_bindir}/bf_tar-db \
 --slave %{_mandir}/man1/bf_tar.1.gz bf_tar.1.gz %{_mandir}/man1/bf_tar-db.1.gz

%postun -n %{_name}-db
if [ ! -f %{_bindir}/bogofilter-db ] ; then
	%{_sbindir}/update-alternatives --remove bogofilter %{_bindir}/bogofilter-db
fi

%files -n %{_name}-common
%defattr(-,root,root)
%{_bindir}/bogoupgrade
%config(noreplace) %{_sysconfdir}/bogofilter.cf
%{_datadir}/%{_name}

%files -n %{_name}-doc
%defattr(-,root,root)
%doc AUTHORS COPYING GETTING.STARTED NEWS README* RELEASE.NOTES*
%doc TODO bogofilter.cf.example
%doc doc/README* doc/bogofilter-SA-* doc/*.html doc/integrating*
%doc doc/programmer/ doc/rpm.notes.BerkeleyDB
%doc %{_defaultdocdir}/bogofilter-doc/README.SUSE
%{_mandir}/man1/bogofilter.1%{ext_man}
%{_mandir}/man1/bogolexer.1%{ext_man}
%{_mandir}/man1/bogoupgrade.1%{ext_man}
%{_mandir}/man1/bogotune.1%{ext_man}
%{_mandir}/man1/bogoutil.1%{ext_man}
%{_mandir}/man1/bf_compact.1%{ext_man}
%{_mandir}/man1/bf_copy.1%{ext_man}
%{_mandir}/man1/bf_tar.1%{ext_man}

%files -n %{_name}-db
%defattr(-,root,root)
%ghost %{_sysconfdir}/alternatives/bogofilter
%ghost %{_sysconfdir}/alternatives/bogolexer
%ghost %{_sysconfdir}/alternatives/bogotune
%ghost %{_sysconfdir}/alternatives/bogoutil
%ghost %{_sysconfdir}/alternatives/bf_compact
%ghost %{_sysconfdir}/alternatives/bf_copy
%ghost %{_sysconfdir}/alternatives/bf_tar
%ghost %{_sysconfdir}/alternatives/bogofilter.1.*
%ghost %{_sysconfdir}/alternatives/bogolexer.1.*
%ghost %{_sysconfdir}/alternatives/bogotune.1.*
%ghost %{_sysconfdir}/alternatives/bogoutil.1.*
%ghost %{_sysconfdir}/alternatives/bf_compact.1.*
%ghost %{_sysconfdir}/alternatives/bf_copy.1.*
%ghost %{_sysconfdir}/alternatives/bf_tar.1.*
%{_bindir}/bogofilter
%{_bindir}/bogolexer
%{_bindir}/bogotune
%{_bindir}/bogoutil
%{_bindir}/bf_compact
%{_bindir}/bf_copy
%{_bindir}/bf_tar
%{_bindir}/*-db
%{_mandir}/man1/*-db.1%{ext_man}
%endif

%if "%{flavor}" == "kyotocabinet"
%files -n %{_name}-kyotocabinet
%defattr(-,root,root)
%ghost %{_sysconfdir}/alternatives/bogofilter
%ghost %{_sysconfdir}/alternatives/bogolexer
%ghost %{_sysconfdir}/alternatives/bogotune
%ghost %{_sysconfdir}/alternatives/bogoutil
%ghost %{_sysconfdir}/alternatives/bf_compact
%ghost %{_sysconfdir}/alternatives/bf_copy
%ghost %{_sysconfdir}/alternatives/bf_tar
%ghost %{_sysconfdir}/alternatives/bogofilter.1.*
%ghost %{_sysconfdir}/alternatives/bogolexer.1.*
%ghost %{_sysconfdir}/alternatives/bogotune.1.*
%ghost %{_sysconfdir}/alternatives/bogoutil.1.*
%ghost %{_sysconfdir}/alternatives/bf_compact.1.*
%ghost %{_sysconfdir}/alternatives/bf_copy.1.*
%ghost %{_sysconfdir}/alternatives/bf_tar.1.*
%{_bindir}/bogofilter
%{_bindir}/bogolexer
%{_bindir}/bogotune
%{_bindir}/bogoutil
%{_bindir}/bf_compact
%{_bindir}/bf_copy
%{_bindir}/bf_tar
%{_bindir}/*-kyotocabinet
%{_mandir}/man1/*-kyotocabinet.1%{ext_man}
%endif

%if "%{flavor}" == "sqlite3"
%files -n %{_name}-sqlite3
%defattr(-,root,root)
%ghost %{_sysconfdir}/alternatives/bogofilter
%ghost %{_sysconfdir}/alternatives/bogolexer
%ghost %{_sysconfdir}/alternatives/bogotune
%ghost %{_sysconfdir}/alternatives/bogoutil
%ghost %{_sysconfdir}/alternatives/bf_compact
%ghost %{_sysconfdir}/alternatives/bf_copy
%ghost %{_sysconfdir}/alternatives/bf_tar
%ghost %{_sysconfdir}/alternatives/bogofilter.1.*
%ghost %{_sysconfdir}/alternatives/bogolexer.1.*
%ghost %{_sysconfdir}/alternatives/bogotune.1.*
%ghost %{_sysconfdir}/alternatives/bogoutil.1.*
%ghost %{_sysconfdir}/alternatives/bf_compact.1.*
%ghost %{_sysconfdir}/alternatives/bf_copy.1.*
%ghost %{_sysconfdir}/alternatives/bf_tar.1.*
%{_bindir}/bogofilter
%{_bindir}/bogolexer
%{_bindir}/bogotune
%{_bindir}/bogoutil
%{_bindir}/bf_compact
%{_bindir}/bf_copy
%{_bindir}/bf_tar
%{_bindir}/*-sqlite3
%{_mandir}/man1/*-sqlite3.1%{ext_man}
%endif

%changelog
* Wed Nov  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to _multibuild: with RPM 4.16, we can no longer use
  make_install in the build phase, as %%install will always empty
  DESTDIR.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Mar 13 2019 olaf@aepfle.de
- The previous change added strict versioned Requires from and to a
  noarch subpkg. The release part can not be used in this case
  because the noarch packages will most likely be shared across
  architectures, and different architectures may have different
  release numbers.
  Relax the Requires again
* Wed Mar  6 2019 olaf@aepfle.de
- Swallow old bogofilter pkgs in the db subpkg (bsc#1128219)
  fix change from April 2015
- Require subpkgs from the very same build
* Mon Apr 10 2017 mpluskal@suse.com
- Small spec file cleanup
- Adjust usage of update-alternatives
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly package _docdir, fix build with rpm 4.13.
* Wed Dec 23 2015 p.drouand@gmail.com
- Replace tokyocabinet with kyotocabinet following kyotocabinet
  upstream recommendations
  * Replace libtokyocabinet-devel with libkyotocabinet-devel
  * Add bogofilter-kyotocabinet.patch
  * Rename tokyocabinet with kyotocabinet
- Add autoconf and automake build dependencies; needed because of
  bogofilter-kyotocabinet.patch
* Wed May  6 2015 lmuelle@suse.com
- Add README.SUSE to the doc package.
* Thu Apr 30 2015 lmuelle@suse.com
- Provide and obsolete bogofilter from the db subpackage to ensure we stay
  with the same back-end in the update case.
- Require a backend package from the common package.
- Split of the documentation into an independent package.
- Tag the common and doc package as noarch post-11.1.
* Sat Apr 18 2015 mpluskal@suse.com
- Build different backends
  * sqlite3 db and tokyocabinet
  * switch between them using update-alternatives
- Disable checks as they do not work with suffixed builds
* Sun Apr  5 2015 mpluskal@suse.com
- Update dependencies
  * use shared gsl
- Cleanup spec-file with spec-cleaner
- Change backend from libdb to sqlite3 for post-13.2 systems
* Tue Jul 23 2013 lmuelle@suse.com
- Update to version 1.2.4.
  * Fix three crashes in command line and environment variable parsers
    that caused NULL pointer dereferences with long option variants
    of bogofilter --syslog-tag, or bogoutil --timestamp-date, or when
    bogotune -M<file> cannot derive the bogofilter directory.
  * Add getopt_long_chk(), a getopt_long variant that checks if the
    overlapping short and long options agree on whether their argument
    is not required, mandatory, or optional.  If they disagree, the
    program aborts.
  * Fix a crash in command line parser that causes a NULL pointer
    dereference when --db-cachesize is used without argument.
    Found with getopt_long_chk().
  * Change lexer API/ABI a bit so as to work with flex 2.5.36 generated
    lexers (for instance, on Fedora 18 "Spherical Cow") that flip the
    type of yyleng from int to size_t. We use a signed long internally.
  * Fix XML form of Bulgarian FAQ so that it validates;
    and validate XHTML at build time.
  * Mark Berkeley DB 5.2.42 and 5.3.21 supported.
* Mon Dec  3 2012 lmuelle@suse.com
- Update to version 1.2.3.
  * Update configure.ac to avoid autoconf 2.68 warnings, by
    (a) quoting the first AC_RUN_IFELSE argument, an
    AC_LANG_PROGRAM(), with [ ], and
    (b) providing an explicit "true" assumption for Berkeley DB
    capabilities to avoid cross-compilation warnings.
  * Security bugfix; (CVE-2012-5468); (bnc#792939),
    Fix a heap corruption in base64 decoder on invalid input.
    http://bogofilter.sourceforge.net/security/bogofilter-SA-2012-01
  * Added bogofilter-faq-bg.html, a Bulgarian translation of the FAQ.
  * Mark "Berkeley DB 5.1.19: (August 27, 2010)" supported.
- Update to version 1.2.2.
  * Use a better PRNG for random sleeps. That is arc4random() where
    available, and drand48() elsewhere.
  * Assorted fixes for issues found with clang analyzer:
    + Fix a potential NULL deference
    + Fix a potential division by zero
    + Remove dead assignments and increments
  * Update Doxyfile and source contrib/bogogrep.c for docs, too.
  * Security bugfix, CVE-2010-2494:
    Fix a heap corruption in base64 decoder on invalid input.
    Analysis and patch by Julius Plenz <plenz@cis.fu-berlin.de>.
    Please see doc/bogofilter-SA-2010-01 for details.
  * Updated sendmail milter contrib/bogofilter-milter.pl to v1.??????
  * Bump supported/minimum SQLite3 versions and warning threshold.
    See doc/README.sqlite for details.
  * Mark BerkeleyDB 4.8.26 and 5.0.21 supported.
  * Make t.maint more robust; ignore .ENCODING token. To fix test
    failures on, for instance, FreeBSD with unicode enabled.
  * Fix several compiler warnings "array subscript has type 'char'", by
    casting the arguments to unsigned char.
  * Split error messages for ENOENT and EINVAL into new function.
  * Avoid divison by zero in robx computation by checking if there are at
    least one ham message and one spam message registered.
  * contrib/spamitarium.pl updated to version 0.4.0
  * Updated and integrated Ted Phelps's "Patch to prevent .ENCODING from
    being discarded by bogoutil -m" (SourceForge Patch #1743984).
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jul  7 2010 lmuelle@suse.de
- Fix a heap corruption in base64 decoder on invalid input; CVE-2010-2494;
  (bnc#619847).
* Tue Jan 12 2010 coolo@novell.com
- fix build on non-arm
* Tue Oct 27 2009 bitshuffler@opensuse.org
- Update to version 1.2.1.
  + Update configure to use "host" rather than "target", to match the
    newer autotools cross-build semantics. Untested.
    Developers changing the build system and users who build from SVN
    will now need automake 1.9 and autoconf 2.60.
  + Fix Christian Frommeyer's MIME decoding bug, Ubuntu/Launchpad Bug
    [#320829]. As a side effect, also fixes misattribution of MIME bodies
    as MIME headers with mime: tag.  Original bug report:
    https://bugs.launchpad.net/ubuntu/+source/bogofilter/+bug/320829
    Before this fix, bogofilter did not properly MIME-decode the first
    line in a body. This was especially bad with Christian's samples
    where the whole body was only one long base64 line.
  + Removed two scripts that are auto-built.
  + Added test case for Stephen Davies' Q-P EOL problem (see below).
  + Fixed EOL problem in quoted_printable text. Problem reported by
    Stephen Davies and identified by Pavel Kankovsky
  + Promoted to "stable"
* Thu May  7 2009 lmuelle@suse.de
- Update to version 1.2.0.
  + Flex-2.5.35 has fix for memory allocation problem in 2.5.4, 2.5.31, and
    2.5.33, making bogofilter's flex patch obsolete.
  + Bogofilter now uses listsort in place of qsort.
  + Added token-count=n, token-count-min=n, and token-count-max=n options.
  + Minor code cleanups.
  + spamitarium.pl updated to version 0.3.0
  + update bf_compact documentation by removing explicit Berkeley DB
    references, as it has been fixed to work with other database drivers in
    March 2008.
  + bf_compact, bf_copy and bf_tar now support transformed program names
  + Update sqlite3 adaptor to take advantage of sqlite3_prepare_v2() API
    function that appeared in SQLite 3.3.9. The new _v2 interface allows for
    more specific error messages when executing SQL statements.  Also enable
    extended result codes for more precise error reporting.
  + Update doc/integrating-with-postfix: the script now suggests sendmail -G
  - i (where -G will be ignored by Postfix before 2.3) to tell Postfix it's a
    gateway submission, not an original injection; the filter pipe(8) magic
    for master.cf now suggests flags=Rq (was flags=R), as per Postfix's
    FILTER_README.
  + Drop support for systems that reverse setvbuf arguments. The last systems
    to do that are reported to be shipped in 1987 by the autoconf manual, so
    ditch them.
* Wed Feb 18 2009 lmuelle@suse.de
- Update to version 1.1.7.
  + Updated sendmail milter contrib/bogofilter-milter.pl to v1.45
  + Added maildir training info to English and French FAQs.
  + Fix uninitialized variable in lexer.c when unicode is disabled.
  + In process_arg functions use the val parameter rather than optarg.
  + Function process_arg now has the same prototype for
    bogofilter, bogolexer, bogoutil, and bogotune.  The proper
    version is called by function read_config_file for all
    programs.
  + Fixed syntax errors in t.valgrind test
  + bf_compact now supports compacting databases that use QDBM, Tokyo
    Cabinet or SQLite3 and is covered by the test suite.
  + bf_compact now verifies databases before dumping them, to avoid
    getting into an unterminated loop and wasting all diskspace.
  + Bogoupgrade now verifies databases before dumping them, to avoid
    getting into an unterminated loop and burning all memory or disk
    space when the database is corrupt.
  + Bogoupgrade now uses Pod::Usage to print usage/help, prints error
    messages that are a bit more concise and validates arguments a bit
    stricter.
  + Bump required sqlite version to 3.5.4, earlier versions could
    sometimes corrupt the database. Update install-staticdblibs.sh.
    Bogofilter will complain when used with older versions.
  + bf_compact problem fixed.
- Update to version 1.1.6.
  + Transaction support added for TokyoCabinet datastore.
  + Bump required sqlite version to 3.4.2 and fix related compiler
    warnings. Bogofilter will complain when used with older versions.
  + Support for TokyoCabinet datastore added.
  + doc/README.db was updated to BerkeleyDB 4.6
  + doc/README.db: section 3.5 was added, with information on how to
    resolve "Logging region out of memory; you may need to increase its
    size", section 4.2 now documents set_lg_regionmax.
  + The install-staticdblibs.sh script was relicensed under GNU GPL v3,
    adjusted to download Berkeley DB 4.2 from oracle.com, adds patch #5,
    and updated to build SQLite 3.4.1. In order to for a rebuild of the
    updated library, do: rm -rf /opt/db-4.2-lean /opt/sqlite-3-lean
    and re-run the script.
  + The recommended minimum sqlite3 version is now 3.4.0, bogofilter will
    warn if used with older versions. Bugs that could cause database
    corruption in rare circumstances have been fixed in sqlite3.
    See doc/README.sqlite for details.
  + Updated sendmail milter contrib/bogofilter-milter.pl to v1.27
  + Add '--spam-header-place={header}' to specify header line
    before which the X-Bogosity line is placed.
  + Support --db-verify for sqlite3.
  + Fix defect where the database verification method would not be called
    for traditional Berkeley DB databases. Reported by Eric Wood.
  + Fix test suite for situations where there are blanks in the test or
    working directories' names.
  + Repair passthrough defect on systems whose standard system library
    makes a distinction between text and binary mode in stdio stuff.
- Update to version 1.1.5	2007-01-14 (released) 2007-01-25 (declared stable)
  + Fixed Makefile dependency problem.
  + Fixed block-on-subnets problem.
  + Added block-on-subnets regression test.
- Update to version 1.1.4	2007-01-01 (released)
  + Update copyright notices.
  + Add GSL dependency to bogofilter target to support parallel
    makes.
  + Fixed problem in flex-2.5.4 patch.
- Update to version 1.1.3	2006-12-03 (released) 2006-12-20 (declared stable)
  + Fixed typo in configure.ac.
- Update to version 1.1.2	2006-12-02 (released)
  + Revise install-staticlibs.sh's links for retrieving database
    tarball and patches.
  + Revise make rules for generating statically linked RPM.
  + Provide separate flex patches for 2.5.4 and 2.5.3x
  + Updated file comment for lexer_v3.l and removed unneeded
    rules T1, T12, SHORT_TOKEN, and TOKEN_12.
  + Miscellaneous minor cleanups of lexer_v3.l classes and rules.
  + Patch flex skeleton code problem which can cause a seg-fault.
  + Fix processing of "--unicode=no" option.
  + Fix prefixes for ip address and url tokens.  Restore colon
    that was dropped in token.c edit for bogofilter-1.1.0.
  + Fixed problem parsing message ids, which can cause a
    seg-fault on an x86_64.
  + Added '--ham-true' option for bogofilter (to match docs)
  + FAQ's updated to point to current sylpheed-claws wiki
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Mon Sep  4 2006 lmuelle@suse.de
- Update to version 1.1.1.
  + Fixed minor header/body multi-word token defect.
  + Add large file support for 32-bit systems.
    (_FILE_OFFSET_BITS/_LARGE_FILE).
  + Fix lexer_v3.l format string mismatch that broke debugging code on
    64-bit systems.
  + Add multi-word token support to bogoutil & bogotune.
  + Clean up token prefixing.
  + Clean up queue-id processing.
  + Add max-multi-token-len checks.
  + Add min-token-len check (with exemption for 2 character
    money amounts which bogofilter has long accepted).
  + Add "short token" pattern to lexer
  + Add options for min/max token length, multi-token count, and
    max multi-token length.
  + Corrected option parsing in bogotune to support -n ham1 ham2
  - s spam1 spam2 as suggested by bogotune -h; broken since 0.93.2.
  + Corrected problem with bogotune's -D option (thanks to Jason Smith).
  + Flush output after writing spam header line and/or message body.
  + When database is near to maximum allowed size, allow reading
    it and disallow writing to it.
  + Fix formatting of Rtable output when in the message header,
    this keeps verbose passthrough modes RFC-822/2822 compliant.
  + Fixed --input-file and --output-file command line options.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 lmuelle@suse.de
- Update to version 1.0.1; CVE-2005-4591, CVE-2005-4592; [#142490].
* Fri Dec  2 2005 lmuelle@suse.de
- Update to version 1.0.0.
* Thu Nov 24 2005 lmuelle@suse.de
- Ensure to set permissions of all scripts with a hash-bang starting header in
  the contrib dir to 0755.
* Tue Nov 22 2005 lmuelle@suse.de
- Update to version 0.96.6.
* Tue Nov 15 2005 uli@suse.de
- hardwire shared DB test to yes on ARM
* Thu Oct 27 2005 lmuelle@suse.de
- Update to version 0.96.2.
* Fri Jul  8 2005 lmuelle@suse.de
- Update to version 0.95.2.
* Mon Jun 20 2005 lmuelle@suse.de
- Update to version 0.94.14.
* Wed May 18 2005 lmuelle@suse.de
- Remove superfluous, twice installed man pages from the doc dir.
* Tue May 17 2005 lmuelle@suse.de
- Update to version 0.94.12, [#84028].
* Tue Apr 26 2005 uli@suse.de
- disabled make check on ARM (may hang QEMU)
* Tue Feb  1 2005 ro@suse.de
- added check-build.sh (need 2.6.X kernel at least)
* Mon Dec  6 2004 lmuelle@suse.de
- Update to version 0.93.2.
* Thu Nov 25 2004 ro@suse.de
- fix build on db-4.3
* Tue Oct 26 2004 lmuelle@suse.de
- Update to version 0.92.8, [#47636].
* Thu Oct 14 2004 mmj@suse.de
- Update to version 0.92.7
* Thu Oct 14 2004 lmuelle@suse.de
- Update to version 0.92.6.
* Sat Aug  7 2004 lmuelle@suse.de
- Update to version 0.92.4.
* Thu Jul 15 2004 lmuelle@suse.de
- Update to version 0.92.2.
* Mon Jun 28 2004 mmj@suse.de
- Update to 0.92.0.
* Sat Apr 10 2004 lmuelle@suse.de
- Update to version 0.17.5
* Fri Mar  5 2004 lmuelle@suse.de
- remove twice listed bogotune man page from file list
* Thu Mar  4 2004 mmj@suse.de
- Update to 0.16.4
* Wed Jan  7 2004 lmuelle@suse.de
- update to version 0.15.13.1
* Mon Nov 10 2003 lmuelle@suse.de
- update to version 0.15.8
- add norootforbuild to the spec file
* Thu Aug 14 2003 lmuelle@suse.de
- update to version 0.14.4
* Thu Jul  3 2003 lmuelle@suse.de
- update to version 0.13.7.2
* Fri Jun  6 2003 lmuelle@suse.de
- update to version 0.13.6.2
* Sat Apr 19 2003 lmuelle@suse.de
- update to version 0.11.2
* Wed Apr  9 2003 lmuelle@suse.de
- switch to the upstream patch to work with current coreutils
* Tue Apr  8 2003 lmuelle@suse.de
- update to version 0.11.1.8
* Thu Mar 27 2003 lmuelle@suse.de
- update to version 0.11.1.4
* Thu Mar  6 2003 lmuelle@suse.de
- update to version 0.11.1
* Mon Feb 24 2003 lmuelle@suse.de
- update to version 0.10.3.1
* Tue Feb 11 2003 lmuelle@suse.de
- update to version 0.10.2
* Sun Dec  8 2002 lmuelle@suse.de
- update to version 0.9.1.2
* Sun Dec  1 2002 lmuelle@suse.de
- update to version 0.9.1
* Tue Nov 12 2002 lmuelle@suse.de
- remove superfluous aclocal, libtoolize, autoheader, automake, autoconf
* Mon Nov 11 2002 lmuelle@suse.de
- update to version 0.8.0
- make use of autoheader and automake; call aclocal first
* Tue Nov  5 2002 lmuelle@suse.de
- update to version 0.7.6
* Mon Nov  4 2002 lmuelle@suse.de
- add patch for getopt call to fix -d option from Carsten Hoeger
  <choeger@suse.de>
* Sun Oct 20 2002 lmuelle@suse.de
- inital SuSE RPM based on ESR spec file
